@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.115_01';
+our $VERSION = '0.116_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Feb  7 17:11:06 2019 GMT
+# on Fri Feb 15 17:21:25 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1709,7 +1709,7 @@ __PACKAGE__->status( add => 24907, iridium => '-', 'Iridium 22', 'Tumbling' );
 __PACKAGE__->status( add => 24925, iridium => '-', 'Dummy mass 1', 'Tumbling' );
 __PACKAGE__->status( add => 24926, iridium => '-', 'Dummy mass 2', 'Tumbling' );
 __PACKAGE__->status( add => 24944, iridium => '-', 'Iridium 29', 'Tumbling' );
-__PACKAGE__->status( add => 24945, iridium => 'S', 'Iridium 32', '' );
+__PACKAGE__->status( add => 24945, iridium => '-', 'Iridium 32', 'Tumbling' );
 __PACKAGE__->status( add => 24946, iridium => '-', 'Iridium 33', 'Tumbling' );
 __PACKAGE__->status( add => 24947, iridium => 'D', 'Iridium 27', 'Decayed 2002-02-01' );
 __PACKAGE__->status( add => 24948, iridium => '-', 'Iridium 28', 'Tumbling' );
@@ -1774,7 +1774,7 @@ __PACKAGE__->status( add => 25577, iridium => 'D', 'Iridium 20', 'Decayed 2018-1
 __PACKAGE__->status( add => 25578, iridium => 'D', 'Iridium 11', 'Decayed 2018-10-22' );
 __PACKAGE__->status( add => 25777, iridium => '+', 'Iridium 14', '' );
 __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-05-24' );
-__PACKAGE__->status( add => 27372, iridium => '+', 'Iridium 91', '' );
+__PACKAGE__->status( add => 27372, iridium => 'S', 'Iridium 91', '' );
 __PACKAGE__->status( add => 27373, iridium => 'D', 'Iridium 90', 'Decayed 2019-01-23' );
 __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-04-18' );
 __PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
@@ -1783,9 +1783,9 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 7
+# Operational [+]: 6
 #       Spare [S]: 6
-#    Tumbling [-]: 32
+#    Tumbling [-]: 33
 #     Decayed [D]: 52
 
 1;
